@@ -1,37 +1,26 @@
 #' @useDynLib mtdesign
 #' @importFrom Rcpp sourceCpp
 
-.onLoad <- function(libname, pkgname) {
-  futile.logger::flog.layout(
-    futile.logger::layout.format("~n ~t ~l ~f: ~m")
-  )
-}
-
 .onUnload <- function(libpath) {
   library.dynam.unload("mtdesign", libpath)
 }
 
 isBasicGrid <- function(grid) {
-  futile.logger::flog.debug("Entry")
   if (!methods::is(grid, "data.frame")) {
     return(FALSE)
   }
   columnsRequired <- c("p0", "p1", "nStage1", "nTotal", "rFutility", "rTotal")
   rv <- length(intersect(names(grid), columnsRequired)) == length(columnsRequired)
-  futile.logger::flog.debug("Exit")
   return(rv)
 }
 
 isManderGrid <- function(grid) {
-  futile.logger::flog.debug("Entry")
   columnsRequired <- c("rSuccess")
   rv <- isBasicGrid(grid) & length(intersect(names(grid), columnsRequired)) == length(columnsRequired)
-  futile.logger::flog.debug("Exit")
   return(rv)
 }
 
 isAugmented <- function(grid) {
-  futile.logger::flog.debug("Entry")
   if (!isBasicGrid(grid)) {
     return(NA)
   }
@@ -39,7 +28,6 @@ isAugmented <- function(grid) {
     "Type1", "Type2", "PETNull", "PETAlt", "AveSizeNull",
     "AveSizeAlt"
   )
-  futile.logger::flog.debug("Exit")
   rv <- length(intersect(names(grid), columnsRequired)) == length(columnsRequired)
   return(rv)
 }
@@ -51,11 +39,12 @@ isAugmented <- function(grid) {
 #' @param alpha the desired (one-sided) type 1 error rate
 #' @param beta the desired type 2 error rate
 #' @param power an alternative to \code{beta}
-#' @param nMin the lower bound for the search grid.  If \code{NA},
-#' \code{searchBounds} is called to provide an appropriate value
-#' @param nMax the lower bound for the search grid.  If \code{NA},
-#' \code{searchBounds} is called to provide an appropriate value
+#' @param nMin the lower bound for the search grid.  If \code{NA}
+#' \code{searchBounds}, is called to provide an appropriate value
+#' @param nMax the lower bound for the search grid.  If \code{NA}
+#' \code{searchBounds}, is called to provide an appropriate value
 #' @param mander is a Mander & Thompson or a Simon's design required?
+#' @param verbose print messages describing workflow?
 #' @return a tibble.  See Usage notes for a list and description of columns.
 #' @examples
 #' # Standard use for a Simon's 2-stage design
@@ -72,8 +61,8 @@ createGrid <- function(p0,
                        power = ifelse(is.na(beta), 0.9, 1 - beta),
                        nMin = NA,
                        nMax = NA,
-                       mander = TRUE) {
-  futile.logger::flog.debug("Entry")
+                       mander = TRUE,
+                       verbose = FALSE) {
   # Validation
   if (is.na(p0)) stop("You must provide a value for p0")
   if (is.na(p1)) stop("You must provide a value for p1")
@@ -103,13 +92,13 @@ createGrid <- function(p0,
   bounds <- searchBounds(p0, p1, alpha, beta, twoSided = FALSE)
   if (is.na(nMin)) {
     nMin <- bounds["min"]
-    futile.logger::flog.debug(paste0("Using default value for nMin: ", nMin))
+    if (verbose) message(paste0("Using default value for nMin: ", nMin))
   }
   if (is.na(nMax)) {
     nMax <- bounds["max"]
-    futile.logger::flog.debug(paste0("Using default value for nMax: ", nMax))
+    if (verbose) message(paste0("Using default value for nMax: ", nMax))
   }
-  futile.logger::flog.debug(
+  if (verbose) message(
     paste0(
       "One stage sample size is ",
       bounds["n"],
@@ -139,11 +128,11 @@ createGrid <- function(p0,
   # so build up and filter in stages.
   d <- tibble::tibble() %>% tidyr::expand(nTotal, nStage1)
   d <- d %>% dplyr::filter(nTotal >= nMin, nStage1 < nTotal)
-  futile.logger::flog.trace(paste0("Building grid - nTotal, nStage1: ", nrow(d)))
+  if (verbose) message(paste0("Building grid - nTotal, nStage1: ", nrow(d)))
 
   d <- d %>% tidyr::expand(tidyr::nesting(nTotal, nStage1), rTotal)
   d <- d %>% dplyr::filter(rTotal < nTotal)
-  futile.logger::flog.trace(paste0("Building grid - nTotal, nStage1, rTotal: ", nrow(d)))
+  if (verbose) message(paste0("Building grid - nTotal, nStage1, rTotal: ", nrow(d)))
 
   d <- d %>% tidyr::expand(tidyr::nesting(nTotal, nStage1, rTotal), rFutility)
   d <- d %>% dplyr::filter(
@@ -152,7 +141,7 @@ createGrid <- function(p0,
     rFutility < nStage1,
     (rTotal - rFutility) < (nTotal - nStage1)
   )
-  futile.logger::flog.trace(
+  if (verbose) message(
     paste0(
       "Building grid - nTotal, nStage1, rTotal, rFutility: ",
       nrow(d)
@@ -169,7 +158,7 @@ createGrid <- function(p0,
         rSuccess > rFutility,
         rSuccess <= nStage1
       )
-    futile.logger::flog.trace(
+    if (verbose) message(
       paste0(
         "Building grid - nTotal, nStage1, rTotal, rFutility, rSuccess: ",
         nrow(d)
@@ -186,8 +175,6 @@ createGrid <- function(p0,
   if (!mander) {
     d <- d %>% dplyr::select(-rSuccess)
   }
-  futile.logger::flog.trace(paste0("Grid has ", nrow(d), " rows."))
-  futile.logger::flog.debug("Exit")
   return(d)
 }
 
@@ -205,7 +192,6 @@ createGrid <- function(p0,
 #' \code{floor()} and \code{ceiling()} are applied as appropriate.
 #' @export
 searchBounds <- function(p0, p1, alpha = 0.05, beta = 0.2, twoSided = TRUE) {
-  futile.logger::flog.debug("Entry")
 
   if (twoSided) alpha <- alpha / 2
   # Sample size formula based on Fleiss JL, Levin B and Paik MC (2003).
@@ -220,7 +206,6 @@ searchBounds <- function(p0, p1, alpha = 0.05, beta = 0.2, twoSided = TRUE) {
   n <- n + 1 / abs(p0 - p1)
   # Bounds based on ????
   rv <- c("n" = ceiling(n), "min" = floor(n * 0.8), "max" = ceiling(n * 2))
-  futile.logger::flog.debug("Exit")
   return(rv)
 }
 
@@ -243,17 +228,15 @@ searchBounds <- function(p0, p1, alpha = 0.05, beta = 0.2, twoSided = TRUE) {
 #'   augmentGrid(parallel = FALSE)
 #' @export
 augmentGrid <- function(d, parallel = TRUE, cores = NA, minChunkSize = 100000) {
-  futile.logger::flog.debug("Entry")
   k <- d %>% nrow()
   if (parallel) {
     if (k < minChunkSize) {
-      futile.logger::flog.info(
+      warning(
         paste0(
           "Parallelisation has been requested, but the grid size [", k,
           "] is less than the minimum chunk size [", minChunkSize,
           "].  Parallelisation will not occur"
-        ),
-        namespace = "mtdesign"
+        )
       )
       parallel <- FALSE
     }
@@ -265,22 +248,15 @@ augmentGrid <- function(d, parallel = TRUE, cores = NA, minChunkSize = 100000) {
     if (is.na(cores)) {
       cores <- parallel::detectCores()
     }
-    futile.logger::flog.trace("Starting parallelisation")
-    futile.logger::flog.trace(paste0("Requesting ", cores, " cores"))
-    futile.logger::flog.trace(paste0("k is ", k))
     chunkSize <- ceiling(k / cores)
-    futile.logger::flog.trace(paste0("Creating chunk list.  Chunk size is ", chunkSize))
     tmp <- d %>% dplyr::mutate(Chunk = ceiling(dplyr::row_number() / chunkSize))
     parallelList <- tmp %>%
       dplyr::group_by(Chunk) %>%
       dplyr::group_map(function(.x, .y) .x)
-    futile.logger::flog.trace("Creating cluster")
     cluster <- parallel::makeCluster(cores)
-    futile.logger::flog.trace("Initialising nodes")
     parallel::clusterEvalQ(cluster, {
       library(parallel)
     })
-    futile.logger::flog.trace("Running parLapply")
     d <- parallel::parLapply(
       cluster,
       parallelList,
@@ -288,11 +264,10 @@ augmentGrid <- function(d, parallel = TRUE, cores = NA, minChunkSize = 100000) {
       parallel = FALSE
     ) %>%
       dplyr::bind_rows()
-    futile.logger::flog.trace("Stopping cluster")
     suppressWarnings(parallel::stopCluster(cluster))
   } else {
     if (k >= 1e6) {
-      futile.logger::flog.info(
+      message(
         paste0(
           "The grid contains ",
           k,
@@ -310,7 +285,6 @@ augmentGrid <- function(d, parallel = TRUE, cores = NA, minChunkSize = 100000) {
   if (isManderGrid(d)) {
     d <- d %>% dplyr::mutate(rSuccess = as.integer(rSuccess))
   }
-  futile.logger::flog.debug("Exit")
   return(d)
 }
 
@@ -374,7 +348,6 @@ obtainDesign <- function(grid = NULL,
                          beta = ifelse(is.null(grid), 0.1, NA),
                          fullGrid = FALSE,
                          ...) {
-  futile.logger::flog.debug("Entry")
   # Initialise
   dots <- list(...)
   # Validate
@@ -391,16 +364,16 @@ obtainDesign <- function(grid = NULL,
       stop("Grid must be a tibble created by createGrid()")
     }
     if (!is.na(p0)) {
-      futile.logger::flog.warn("A valid grid has been supplied.  Ignoring p0...")
+      warning("A valid grid has been supplied.  Ignoring p0...")
     }
     if (!is.na(p1)) {
-      futile.logger::flog.warn("A valid grid has been supplied.  Ignoring p1...")
+      warning("A valid grid has been supplied.  Ignoring p1...")
     }
     if (!is.na(alpha)) {
-      futile.logger::flog.warn("A valid grid has been supplied.  Ignoring alpha...")
+      warning("A valid grid has been supplied.  Ignoring alpha...")
     }
     if (!is.na(beta)) {
-      futile.logger::flog.warn("A valid grid has been supplied.  Ignoring beta...")
+      warning("A valid grid has been supplied.  Ignoring beta...")
     }
   }
 
@@ -437,8 +410,7 @@ obtainDesign <- function(grid = NULL,
       )
     if (nrow(acceptableGrid) == 0) {
       rlang::warn("No acceptable designs were found.")
-      futile.logger::flog.warn("No acceptable designs were found.")
-    }
+     }
 
     rv <- vector("list", 4)
     rv[[1]] <- acceptableGrid %>%
@@ -471,7 +443,6 @@ obtainDesign <- function(grid = NULL,
     }
     rv <- dplyr::bind_rows(rv)
     class(rv) <- class(grid)
-    futile.logger::flog.debug("Exit")
     return(rv)
   }
 }
@@ -490,7 +461,6 @@ obtainDesign <- function(grid = NULL,
 #'   powerPlot(probs = seq(0, 0.5, 0.025))
 #' @export
 powerPlot <- function(grid, probs = seq(0, 1, 0.01)) {
-  futile.logger::flog.debug("Entry")
   if (is.null(grid)) stop("grid cannot be null")
   if (!isBasicGrid(grid)) stop("Grid must be a tibble created by createGrid()")
 
@@ -609,6 +579,5 @@ powerPlot <- function(grid, probs = seq(0, 1, 0.01)) {
     ) +
     ggplot2::theme_light() +
     ggplot2::theme(legend.title = ggplot2::element_blank())
-  futile.logger::flog.debug("Exit")
   return(plot)
 }
